colour.models.dataset.srgb Module — Colour 0.3.0 documentation

# colour.models.dataset.srgb Module

## sRGB Colourspace

Defines the sRGB colourspace:

- `sRGB_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://www.itu.int/dms_pubrec/itu-r/rec/bt/R-REC-BT.709-5-200204-I!!PDF-E.pdf (Last accessed 24 February 2014)

`colour.models.dataset.srgb.` `sRGB_PRIMARIES` = array([[ 0.64, 0.33], [ 0.3 , 0.6 ], [ 0.15, 0.06]])

  sRGB colourspace primaries.

  sRGB_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.srgb.` `sRGB_WHITEPOINT` = (0.31271, 0.32902)

  sRGB colourspace whitepoint.

  sRGB_WHITEPOINT : tuple

`colour.models.dataset.srgb.` `sRGB_TO_XYZ_MATRIX` = array([[ 0.41238656, 0.35759149, 0.18045049], [ 0.21263682, 0.71518298, 0.0721802 ], [ 0.01933062, 0.11919716, 0.95037259]])

  sRGB colourspace to CIE XYZ colourspace matrix.

  sRGB_TO_XYZ_MATRIX : array_like, (3, 3)

`colour.models.dataset.srgb.` `XYZ_TO_sRGB_MATRIX` = array([[ 3.24100326, -1.53739899, -0.49861587], [-0.96922426, 1.87592999, 0.04155422], [ 0.05563942, -0.2040112 , 1.05714897]])

  CIE XYZ colourspace to sRGB colourspace matrix.

  XYZ_TO_sRGB_MATRIX : array_like, (3, 3)

`colour.models.dataset.srgb.` `sRGB_TRANSFER_FUNCTION`(x)

  Transfer function from linear to sRGB colourspace.

  sRGB_TRANSFER_FUNCTION : object

`colour.models.dataset.srgb.` `sRGB_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from sRGB colourspace to linear.

  sRGB_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.srgb.` `sRGB_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e29a50>

  sRGB colourspace.

  sRGB_COLOURSPACE : RGB_Colourspace